==> rk.ANOVA_0.01-6.tar.gz: rk.ANOVA/inst/rkward/plugins/Preparewithinsubjectdata.js <==
// this code was generated using the rkwarddev package.
//perhaps don't make changes here, but in the rkwarddev script instead!

function preprocess(){
	// add requirements etc. here

}

function calculate(){
	// read in variables from dialog
	var vrslDtmstbdt = getValue("vrsl_Dtmstbdt");
	var vrslDpndntrs = getValue("vrsl_Dpndntrs");
	var inpNmfrdpnd = getValue("inp_Nmfrdpnd");
	var inpNmfrxprm = getValue("inp_Nmfrxprm");
	var vrslCssbjctd = getValue("vrsl_Cssbjctd");
	var vrslBtwnsbjc = getValue("vrsl_Btwnsbjc");
	var svbSvrsltst = getValue("svb_Svrsltst");

	// the R code to be evaluated

	var vrslDpndntrsShortname = getValue("vrsl_Dpndntrs.shortname").split("\n").join("\", \"");

	var plainVrslDpndntrsShortname = getValue("vrsl_Dpndntrs.shortname").split("\n").join(", ");

	var vrslCssbjctdShortname = getValue("vrsl_Cssbjctd.shortname");

	var vrslBtwnsbjcShortname = getValue("vrsl_Btwnsbjc.shortname");
	if(vrslDtmstbdt) {
		echo("attach(" + vrslDtmstbdt + ")\nnum.cases <- nrow(" + vrslDtmstbdt + ")\n");
	} else {}
	if(vrslDpndntrs) {
		echo("anova.conditions <- c(\"" + vrslDpndntrsShortname + "\")\nnum.conditions <- length(anova.conditions)\n\n");
	} else {}
	if(vrslBtwnsbjc) {
			var betweenVars = vrslBtwnsbjcShortname.split("\n");
	} else {
			var betweenVars = "";
	}
	echo("anova.data <- data.frame(");
	if(vrslDpndntrs) {
		echo("\n\t" + inpNmfrdpnd + "=c(" + plainVrslDpndntrsShortname + ")");
echo(",\n\t" + inpNmfrxprm + "=factor(rep(anova.conditions, each=num.cases))");
	} else {}
	if(vrslCssbjctd) {
		echo(",\n\t" + vrslCssbjctdShortname + "=factor(rep(" + vrslCssbjctdShortname + ", times=num.conditions))");
	} else {}
	if(vrslBtwnsbjc) {
		for (var i=0, len=betweenVars.length; i<len; ++i ){
			echo(",\n\t"+betweenVars[i]+"=factor(rep("+betweenVars[i]+", times=num.conditions))");
		}
	} else {}
	echo(",\n\tstringsAsFactors=FALSE)\n");
	if(vrslDtmstbdt) {
		echo("detach(" + vrslDtmstbdt + ")\n\n");
	} else {}
}

function printout(){
	// printout the results
	echo("rk.header(\"Prepare within subject data results\", level=1)\n");


	var svbSvrsltst = getValue("svb_Svrsltst");
	var svbSvrsltstActive = getValue("svb_Svrsltst.active");
	var svbSvrsltstParent = getValue("svb_Svrsltst.parent");
	if(svbSvrsltstActive) {
		echo("assign(\"" + svbSvrsltst + "\", anova.data, envir=" + svbSvrsltstParent + ")\n");
	} else {}

}

==> rk.ANOVA_0.01-9.tar.gz: rk.ANOVA/inst/rkward/plugins/Preparewithinsubjectdata.js <==
// this code was generated using the rkwarddev package.
//perhaps don't make changes here, but in the rkwarddev script instead!

function preprocess(){
	// add requirements etc. here

}

function calculate(){
	// read in variables from dialog
	var vrslDtmstbdt = getValue("vrsl_Dtmstbdt");
	var vrslDpndntrs = getValue("vrsl_Dpndntrs");
	var inpNmfrdpnd = getValue("inp_Nmfrdpnd");
	var inpNmfrxprm = getValue("inp_Nmfrxprm");
	var vrslCssbjctd = getValue("vrsl_Cssbjctd");
	var vrslBtwnsbjc = getValue("vrsl_Btwnsbjc");
	var svbSvrsltst = getValue("svb_Svrsltst");

	// the R code to be evaluated
	var vrslDpndntrsShortname = getValue("vrsl_Dpndntrs.shortname").split("\n").join("\", \"");
	var plainVrslDpndntrsShortname = getValue("vrsl_Dpndntrs.shortname").split("\n").join(", ");
	var vrslCssbjctdShortname = getValue("vrsl_Cssbjctd.shortname");
	var vrslBtwnsbjcShortname = getValue("vrsl_Btwnsbjc.shortname");
	if(vrslDtmstbdt) {
		echo("\tattach(" + vrslDtmstbdt + ")\n\tnum.cases <- nrow(" + vrslDtmstbdt + ")\n");
	} else {}
	if(vrslDpndntrs) {
		echo("\tanova.conditions <- c(\"" + vrslDpndntrsShortname + "\")\n\tnum.conditions <- length(anova.conditions)\n\n");
	} else {}
	if(vrslBtwnsbjc) {
		var betweenVars = vrslBtwnsbjcShortname.split("\n");
	} else {
		var betweenVars = "";
	}
	echo("\tanova.data <- data.frame(");
	if(vrslDpndntrs) {
		echo("\n\t\t" + inpNmfrdpnd + "=c(" + plainVrslDpndntrsShortname + ")" + ",\n\t\t" + inpNmfrxprm + "=factor(rep(anova.conditions, each=num.cases))");
	} else {}
	if(vrslCssbjctd) {
		echo(",\n\t\t" + vrslCssbjctdShortname + "=factor(rep(" + vrslCssbjctdShortname + ", times=num.conditions))");
	} else {}
	if(vrslBtwnsbjc) {
		for (var i=0, len=betweenVars.length; i<len; ++i ){
			echo(",\n\t"+betweenVars[i]+"=factor(rep("+betweenVars[i]+", times=num.conditions))");
		}
	} else {}
	echo(",\n\t\tstringsAsFactors=FALSE)\n");
	if(vrslDtmstbdt) {
		echo("\tdetach(" + vrslDtmstbdt + ")\n\n");
	} else {}
}

function printout(){
	// printout the results
	echo("rk.header(\"Prepare within subject data results\", level=1)\n");


	//// save result object
	// read in saveobject variables
	var svbSvrsltst = getValue("svb_Svrsltst");
	var svbSvrsltstActive = getValue("svb_Svrsltst.active");
	var svbSvrsltstParent = getValue("svb_Svrsltst.parent");
	// assign object to chosen environment
	if(svbSvrsltstActive) {
		echo("assign(\"" + svbSvrsltst + "\", anova.data, envir=" + svbSvrsltstParent + ")\n");
	} else {}

}
